import * as i0 from '@angular/core';
import { InjectionToken, NgZone, NgModule, Input, HostBinding, Directive, EventEmitter, ElementRef, Output, ViewChild, ContentChildren, ChangeDetectionStrategy, Component, Injectable } from '@angular/core';
import { datadogLogs } from '@datadog/browser-logs';
import mixpanel from 'mixpanel-browser';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i1$1 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import { map } from 'rxjs';
import * as i2 from '@angular/platform-browser';
import * as i3 from 'asksuite-citrus';

class ConsoleLoggerStrategy {
    log(event, data) {
        console.log(event, data);
    }
    error(event, data) {
        console.error(event, data);
    }
    debug(event, data) {
        console.debug(event, data);
    }
    info(event, data) {
        console.info(event, data);
    }
    warn(event, data) {
        console.warn(event, data);
    }
}

class LoggerService {
    constructor(strategies, parameters, ngZone) {
        this.strategies = strategies;
        this.parameters = parameters;
        this.ngZone = ngZone;
        if (this.strategies.length === 0) {
            this.strategies.push(new ConsoleLoggerStrategy());
        }
    }
    formatData(logLevel, data) {
        if (data instanceof Error) {
            data = this.parseError(data);
        }
        data = this.attachUserData(data);
        data = this.attachTime(data, logLevel);
        data = this.attachAppInfo(data);
        return data;
    }
    attachTime(data, logLevel) {
        return {
            ...data,
            occurredAt: new Date().toJSON(),
            logLevel,
        };
    }
    attachUserData(data) {
        const user = this.parameters?.params?.user;
        const language = this.parameters?.params?.language;
        return {
            ...data,
            user: {
                global: user ? user.role === 'global' : null,
                id: user?.id || null,
                name: user?.name || null,
                email: user?.email || null,
                companyIds: user?.companiesIds || null,
                language,
                userRole: user?.userRole,
            },
        };
    } //
    attachAppInfo(data) {
        return {
            ...data,
            appVersion: this.parameters.params?.version || 'unknown',
            appName: this.parameters.appName,
        };
    }
    parseError(err) {
        return {
            name: err.name || '',
            stack: err.stack || '',
            message: err.message || '',
        };
    }
    handleEvent(logLevel, event, data) {
        try {
            const formattedData = this.formatData(logLevel, data || {});
            this.strategies.forEach((strategy) => {
                switch (logLevel) {
                    case 'log':
                        strategy.log(event, formattedData);
                        break;
                    case 'error':
                        strategy.error(event, formattedData);
                        break;
                    case 'debug':
                        strategy.debug(event, formattedData);
                        break;
                    case 'info':
                        strategy.info(event, formattedData);
                        break;
                    case 'warn':
                        strategy.warn(event, formattedData);
                        break;
                }
            });
        }
        catch (error) {
            console.error(`Não foi possível logar o evento '${logLevel}'`, error);
        }
    }
    log(event, data) {
        this.handleEvent('log', event, data);
    }
    error(event, data) {
        this.handleEvent('error', event, data);
    }
    debug(event, data) {
        this.handleEvent('debug', event, data);
    }
    info(event, data) {
        this.handleEvent('info', event, data);
    }
    warn(event, data) {
        this.handleEvent('warn', event, data);
    }
    setParams(params) {
        this.parameters.params = { ...this.parameters.params, ...params };
        this.strategies.forEach((strategy) => {
            if (strategy.setParams)
                strategy.setParams(this.parameters.params);
        });
    }
}

class MixpanelLoggerStrategy {
    constructor(mixpanel, token, userId, ngZone) {
        this.mixpanel = mixpanel;
        this.token = token;
        this.userId = userId;
        this.ngZone = ngZone;
        this.ngZone.runOutsideAngular(() => {
            this.mixpanel.init(this.token);
            this.setIdentity(this.userId);
        });
    }
    log(event, data) {
        this.mixpanel.track(event, data);
    }
    error(event, data) {
        this.mixpanel.track(event, data);
    }
    debug(event, data) {
        this.mixpanel.track(event, data);
    }
    info(event, data) {
        this.mixpanel.track(event, data);
    }
    warn(event, data) {
        this.mixpanel.track(event, data);
    }
    setParams(params) {
        this.setIdentity(params.user?.id);
    }
    setIdentity(userId) {
        this.ngZone.runOutsideAngular(() => {
            this.mixpanel.identify(String(userId || 'undefined'));
        });
    }
}

class DatadogLoggerStrategy {
    constructor(datadog, config, ngZone) {
        this.datadog = datadog;
        this.config = config;
        this.ngZone = ngZone;
        this.ngZone.runOutsideAngular(() => {
            this.datadog.init(this.config);
        });
    }
    log(event, data) {
        this.datadog.logger.log(event, data);
    }
    error(event, data) {
        this.datadog.logger.error(event, data);
    }
    debug(event, data) {
        this.datadog.logger.debug(event, data);
    }
    info(event, data) {
        this.datadog.logger.info(event, data);
    }
    warn(event, data) {
        this.datadog.logger.warn(event, data);
    }
}

function loggerServiceFactory(ngZone, config, mixpanel, datadog) {
    const strategies = [];
    if (config.externalLogs) {
        if (config.mixpanel) {
            strategies.push(new MixpanelLoggerStrategy(mixpanel, config.mixpanel.token, config.params?.user?.id || 'undefined', ngZone));
        }
        if (config.datadog) {
            strategies.push(new DatadogLoggerStrategy(datadog, config.datadog, ngZone));
        }
    }
    strategies.push(new ConsoleLoggerStrategy());
    return new LoggerService(strategies, config, ngZone);
}

const LOGGER_CONFIG = new InjectionToken('LOGGER_CONFIG');
const MIXPANEL_INSTANCE = new InjectionToken('MIXPANEL_INSTANCE');
const DATADOG_INSTANCE = new InjectionToken('DATADOG_INSTANCE');

class LoggerModule {
    static forRoot(config) {
        return {
            ngModule: LoggerModule,
            providers: [
                { provide: LOGGER_CONFIG, useValue: config },
                { provide: MIXPANEL_INSTANCE, useValue: mixpanel },
                { provide: DATADOG_INSTANCE, useValue: datadogLogs },
                {
                    provide: LoggerService,
                    useFactory: loggerServiceFactory,
                    deps: [NgZone, LOGGER_CONFIG, MIXPANEL_INSTANCE, DATADOG_INSTANCE]
                }
            ],
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: LoggerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.12", ngImport: i0, type: LoggerModule }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: LoggerModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: LoggerModule, decorators: [{
            type: NgModule,
            args: [{}]
        }] });

class SizeableDirective {
    constructor() {
        this.disabled = false;
    }
    ngOnChanges() { }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SizeableDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: SizeableDirective, inputs: { size: "size", disabled: "disabled" }, host: { properties: { "style.width.px": "this.size", "style.height.px": "this.size", "style.fontSize.px": "this.size" }, classAttribute: "sizeable" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SizeableDirective, decorators: [{
            type: Directive,
            args: [{
                    host: {
                        'class': 'sizeable',
                    },
                }]
        }], propDecorators: { size: [{
                type: HostBinding,
                args: ['style.width.px']
            }, {
                type: HostBinding,
                args: ['style.height.px']
            }, {
                type: HostBinding,
                args: ['style.fontSize.px']
            }, {
                type: Input
            }], disabled: [{
                type: Input
            }] } });

class ButtonV2Component {
    set disabled(value) {
        this._disabled = value;
        this.updateChilds();
    }
    // Compute CSS classes based on inputs
    get buttonClasses() {
        let classes = [`-${this.appearance}`, `-${this.shape}`, `-${this.size}`];
        if (this.selected) {
            classes = [...classes, 'selected'];
        }
        if (this.wide) {
            classes = [...classes, '-wide'];
        }
        if (this.iconOnlyButton) {
            classes = [...classes, '-icon-only'];
        }
        if (this.disabled) {
            classes = [...classes, '-disabled'];
        }
        return classes;
    }
    constructor(cd) {
        this.cd = cd;
        this._defaultSize = 16;
        this._disabled = false;
        this.iconOnlyButton = false;
        // Variations as input properties with default values
        this.size = 'medium';
        this.shape = 'square';
        this.appearance = 'opaque';
        this.selected = false;
        this.wide = false;
        this.styles = {};
        // Event handlers
        this.onClick = new EventEmitter();
        this.onFocus = new EventEmitter();
        this.onBlur = new EventEmitter();
    }
    ngAfterContentInit() {
        setTimeout(() => {
            this.setIconOnly();
            this.updateChilds();
        });
    }
    setIconOnly() {
        const childNodes = Array.from(this.contentWrapper.nativeElement.childNodes).filter((node) => {
            if (node.nodeType === Node.COMMENT_NODE)
                return false;
            if (node.nodeType === Node.TEXT_NODE)
                return node.textContent && node.textContent.trim().length > 0;
            return true;
        });
        const isSingleIcon = childNodes.length === 1 && this.sizeableComps?.length === 1;
        if (isSingleIcon)
            this.iconOnlyButton = true;
        this.cd.detectChanges();
    }
    updateChilds() {
        if (!this.sizeableComps)
            return;
        for (const child of this.sizeableComps) {
            child.disabled = this._disabled;
            child.ngOnChanges();
        }
        this.cd.detectChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: ButtonV2Component, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.12", type: ButtonV2Component, isStandalone: true, selector: "ask-button-v2", inputs: { size: "size", shape: "shape", appearance: "appearance", disabled: "disabled", selected: "selected", wide: "wide", styles: "styles" }, outputs: { onClick: "onClick", onFocus: "onFocus", onBlur: "onBlur" }, host: { properties: { "class.-wide": "wide" } }, queries: [{ propertyName: "sizeableComps", predicate: SizeableDirective }], viewQueries: [{ propertyName: "contentWrapper", first: true, predicate: ["contentWrapper"], descendants: true, read: ElementRef }], ngImport: i0, template: "<button\n  class=\"button\"\n  #contentWrapper\n  [ngClass]=\"buttonClasses\"\n  [disabled]=\"_disabled\"\n  [ngStyle]=\"styles\"\n  (click)=\"onClick.emit($event)\"\n  (focus)=\"onFocus.emit($event)\"\n  (blur)=\"onBlur.emit($event)\"\n>\n  <ng-content></ng-content>\n</button>\n\n", styles: [":host{display:block;width:fit-content}:host.-wide{width:100%}.button{display:inline-flex;align-items:center;justify-content:center;gap:8px;width:100%;padding:0;position:relative;cursor:pointer;transition:all .2s ease-in-out;outline:none;border:none;box-sizing:border-box;vertical-align:middle;white-space:nowrap;text-align:center;font-family:Inter;font-size:14px;font-style:normal;font-weight:500;line-height:20px;text-decoration:none}.button.-brand{background:var(--color-background-brand-asksuite-contrast-default);color:var(--color-texticon-inverse-default);--color: var(--color-texticon-inverse-default);border:none}.button.-brand:hover{background:var(--color-background-brand-asksuite-contrast-hovered);color:var(--color-texticon-inverse-default);--color: var(--color-texticon-inverse-default);border:none}.button.-brand:active{background:var(--color-background-brand-asksuite-contrast-pressed);color:var(--color-texticon-brand-asksuite-subtle);--color: var(--color-texticon-brand-asksuite-subtle);border:none}.button.-brand.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-brand.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-brand.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-brand:disabled{background:var(--color-background-disabled);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-opaque{background:var(--color-background-alpha-subtlest-default);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque:hover{background:var(--color-background-alpha-subtlest-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque:active{background:var(--color-background-alpha-subtlest-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-opaque.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-opaque.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-opaque:disabled{background:var(--color-background-disabled);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-opaque-inverse{background:var(--color-background-inverse-default);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque-inverse:hover{background:var(--color-background-accent-grey-inverse-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque-inverse:active{background:var(--color-background-accent-grey-inverse-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque-inverse.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-opaque-inverse.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-opaque-inverse.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-opaque-inverse:disabled{background:var(--color-background-accent-disabled);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-transparent{background:var(--color-background-bounding-box);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent:hover{background:var(--color-background-inverse-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent:active{background:var(--color-background-inverse-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-transparent.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-transparent.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-transparent:disabled{background:var(--color-background-bounding-box);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-transparent-inverse{background:var(--color-background-bounding-box);color:var(--color-texticon-inverse-default);--color: var(--color-texticon-inverse-default);border:none}.button.-transparent-inverse:hover{background:var(--color-background-accent-grey-inverse-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent-inverse:active{background:var(--color-background-accent-grey-inverse-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent-inverse.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-transparent-inverse.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-transparent-inverse.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-transparent-inverse:disabled{background:var(--color-background-bounding-box);color:var(--color-texticon-inverse-disabled);--color: var(--color-texticon-inverse-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-outline{background:var(--color-background-bounding-box);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:1px solid var(--color-border-subtle)}.button.-outline:hover{background:var(--color-background-inverse-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:1px solid var(--color-border-contrast)}.button.-outline:active{background:var(--color-background-inverse-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:1px solid var(--color-border-inverse-contrast)}.button.-outline.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:1px solid var(--color-border-brand-asksuite-bold)}.button.-outline:disabled{background:var(--color-background-disabled);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:1px solid var(--color-border-default);cursor:not-allowed;pointer-events:all}.button.-outline-inverse{background:var(--color-background-bounding-box);color:var(--color-texticon-inverse-default);--color: var(--color-texticon-inverse-default);border:1px solid var(--color-border-white-default)}.button.-outline-inverse:hover{background:var(--color-background-bounding-box);color:var(--color-texticon-brand-asksuite-subtle);--color: var(--color-texticon-brand-asksuite-subtle);border:1px solid var(--color-border-brand-asksuite-subtle)}.button.-outline-inverse:active{background:var(--color-background-alpha-subtlest-pressed);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline-inverse.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline-inverse.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline-inverse.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:1px solid var(--color-border-brand-asksuite-bold)}.button.-outline-inverse:disabled{background:var(--color-background-disabled);color:var(--color-texticon-inverse-disabled);--color: var(--color-texticon-inverse-disabled);border:1px solid var(--color-border-white-disabled);cursor:not-allowed;pointer-events:all}.button.-smallest{height:20px;border-radius:6px;padding:0}.button.-smallest ::ng-deep .sizeable{width:16px;height:16px;font-size:16px}.button.-smallest.-icon-only{padding:0;width:20px}.button.-icon-only-smallest{height:20px;border-radius:6px;padding:0}.button.-icon-only-smallest ::ng-deep .sizeable{width:16px;height:16px;font-size:16px}.button.-icon-only-smallest.-icon-only{padding:0;width:20px}.button.-small{height:24px;border-radius:8px;padding:0 6px}.button.-small ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-small.-icon-only{padding:0;width:24px}.button.-icon-only-small{height:24px;border-radius:8px;padding:0 6px}.button.-icon-only-small ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-icon-only-small.-icon-only{padding:0;width:24px}.button.-medium{height:32px;border-radius:8px;padding:0 12px}.button.-medium ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-medium.-icon-only{padding:0;width:32px}.button.-icon-only-medium{height:32px;border-radius:8px;padding:0 12px}.button.-icon-only-medium ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-icon-only-medium.-icon-only{padding:0;width:32px}.button.-large{height:48px;border-radius:12px;padding:0 18px}.button.-large ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-large.-icon-only{padding:0;width:48px}.button.-icon-only-large{height:48px;border-radius:12px;padding:0 18px}.button.-icon-only-large ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-icon-only-large.-icon-only{padding:0;width:48px}.button.-larger{height:56px;border-radius:12px;padding:0 24px}.button.-larger ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-larger.-icon-only{padding:0;width:56px}.button.-icon-only-larger{height:56px;border-radius:12px;padding:0 24px}.button.-icon-only-larger ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-icon-only-larger.-icon-only{padding:0;width:56px}.button.-rounded{border-radius:52px}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: ButtonV2Component, decorators: [{
            type: Component,
            args: [{ selector: 'ask-button-v2', standalone: true, imports: [CommonModule], host: {
                        '[class.-wide]': 'wide',
                    }, changeDetection: ChangeDetectionStrategy.OnPush, template: "<button\n  class=\"button\"\n  #contentWrapper\n  [ngClass]=\"buttonClasses\"\n  [disabled]=\"_disabled\"\n  [ngStyle]=\"styles\"\n  (click)=\"onClick.emit($event)\"\n  (focus)=\"onFocus.emit($event)\"\n  (blur)=\"onBlur.emit($event)\"\n>\n  <ng-content></ng-content>\n</button>\n\n", styles: [":host{display:block;width:fit-content}:host.-wide{width:100%}.button{display:inline-flex;align-items:center;justify-content:center;gap:8px;width:100%;padding:0;position:relative;cursor:pointer;transition:all .2s ease-in-out;outline:none;border:none;box-sizing:border-box;vertical-align:middle;white-space:nowrap;text-align:center;font-family:Inter;font-size:14px;font-style:normal;font-weight:500;line-height:20px;text-decoration:none}.button.-brand{background:var(--color-background-brand-asksuite-contrast-default);color:var(--color-texticon-inverse-default);--color: var(--color-texticon-inverse-default);border:none}.button.-brand:hover{background:var(--color-background-brand-asksuite-contrast-hovered);color:var(--color-texticon-inverse-default);--color: var(--color-texticon-inverse-default);border:none}.button.-brand:active{background:var(--color-background-brand-asksuite-contrast-pressed);color:var(--color-texticon-brand-asksuite-subtle);--color: var(--color-texticon-brand-asksuite-subtle);border:none}.button.-brand.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-brand.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-brand.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-brand:disabled{background:var(--color-background-disabled);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-opaque{background:var(--color-background-alpha-subtlest-default);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque:hover{background:var(--color-background-alpha-subtlest-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque:active{background:var(--color-background-alpha-subtlest-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-opaque.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-opaque.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-opaque:disabled{background:var(--color-background-disabled);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-opaque-inverse{background:var(--color-background-inverse-default);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque-inverse:hover{background:var(--color-background-accent-grey-inverse-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque-inverse:active{background:var(--color-background-accent-grey-inverse-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-opaque-inverse.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-opaque-inverse.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-opaque-inverse.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-opaque-inverse:disabled{background:var(--color-background-accent-disabled);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-transparent{background:var(--color-background-bounding-box);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent:hover{background:var(--color-background-inverse-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent:active{background:var(--color-background-inverse-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-transparent.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-transparent.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-transparent:disabled{background:var(--color-background-bounding-box);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-transparent-inverse{background:var(--color-background-bounding-box);color:var(--color-texticon-inverse-default);--color: var(--color-texticon-inverse-default);border:none}.button.-transparent-inverse:hover{background:var(--color-background-accent-grey-inverse-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent-inverse:active{background:var(--color-background-accent-grey-inverse-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:none}.button.-transparent-inverse.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-transparent-inverse.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:none}.button.-transparent-inverse.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:none}.button.-transparent-inverse:disabled{background:var(--color-background-bounding-box);color:var(--color-texticon-inverse-disabled);--color: var(--color-texticon-inverse-disabled);border:none;cursor:not-allowed;pointer-events:all}.button.-outline{background:var(--color-background-bounding-box);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:1px solid var(--color-border-subtle)}.button.-outline:hover{background:var(--color-background-inverse-hovered);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:1px solid var(--color-border-contrast)}.button.-outline:active{background:var(--color-background-inverse-pressed);color:var(--color-texticon-contrast);--color: var(--color-texticon-contrast);border:1px solid var(--color-border-inverse-contrast)}.button.-outline.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:1px solid var(--color-border-brand-asksuite-bold)}.button.-outline:disabled{background:var(--color-background-disabled);color:var(--color-texticon-disabled);--color: var(--color-texticon-disabled);border:1px solid var(--color-border-default);cursor:not-allowed;pointer-events:all}.button.-outline-inverse{background:var(--color-background-bounding-box);color:var(--color-texticon-inverse-default);--color: var(--color-texticon-inverse-default);border:1px solid var(--color-border-white-default)}.button.-outline-inverse:hover{background:var(--color-background-bounding-box);color:var(--color-texticon-brand-asksuite-subtle);--color: var(--color-texticon-brand-asksuite-subtle);border:1px solid var(--color-border-brand-asksuite-subtle)}.button.-outline-inverse:active{background:var(--color-background-alpha-subtlest-pressed);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline-inverse.selected{background:var(--color-background-brand-asksuite-subtlest-default);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline-inverse.selected:hover{background:var(--color-background-brand-asksuite-subtlest-hovered);color:var(--color-texticon-brand-asksuite-contrast);--color: var(--color-texticon-brand-asksuite-contrast);border:1px solid var(--color-border-brand-asksuite-contrast)}.button.-outline-inverse.selected:active{background:var(--color-background-brand-asksuite-subtlest-pressed);color:var(--color-texticon-brand-asksuite-bold);--color: var(--color-texticon-brand-asksuite-bold);border:1px solid var(--color-border-brand-asksuite-bold)}.button.-outline-inverse:disabled{background:var(--color-background-disabled);color:var(--color-texticon-inverse-disabled);--color: var(--color-texticon-inverse-disabled);border:1px solid var(--color-border-white-disabled);cursor:not-allowed;pointer-events:all}.button.-smallest{height:20px;border-radius:6px;padding:0}.button.-smallest ::ng-deep .sizeable{width:16px;height:16px;font-size:16px}.button.-smallest.-icon-only{padding:0;width:20px}.button.-icon-only-smallest{height:20px;border-radius:6px;padding:0}.button.-icon-only-smallest ::ng-deep .sizeable{width:16px;height:16px;font-size:16px}.button.-icon-only-smallest.-icon-only{padding:0;width:20px}.button.-small{height:24px;border-radius:8px;padding:0 6px}.button.-small ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-small.-icon-only{padding:0;width:24px}.button.-icon-only-small{height:24px;border-radius:8px;padding:0 6px}.button.-icon-only-small ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-icon-only-small.-icon-only{padding:0;width:24px}.button.-medium{height:32px;border-radius:8px;padding:0 12px}.button.-medium ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-medium.-icon-only{padding:0;width:32px}.button.-icon-only-medium{height:32px;border-radius:8px;padding:0 12px}.button.-icon-only-medium ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-icon-only-medium.-icon-only{padding:0;width:32px}.button.-large{height:48px;border-radius:12px;padding:0 18px}.button.-large ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-large.-icon-only{padding:0;width:48px}.button.-icon-only-large{height:48px;border-radius:12px;padding:0 18px}.button.-icon-only-large ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-icon-only-large.-icon-only{padding:0;width:48px}.button.-larger{height:56px;border-radius:12px;padding:0 24px}.button.-larger ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-larger.-icon-only{padding:0;width:56px}.button.-icon-only-larger{height:56px;border-radius:12px;padding:0 24px}.button.-icon-only-larger ::ng-deep .sizeable{width:20px;height:20px;font-size:20px}.button.-icon-only-larger.-icon-only{padding:0;width:56px}.button.-rounded{border-radius:52px}\n"] }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }], propDecorators: { sizeableComps: [{
                type: ContentChildren,
                args: [SizeableDirective]
            }], contentWrapper: [{
                type: ViewChild,
                args: ['contentWrapper', { read: ElementRef }]
            }], size: [{
                type: Input
            }], shape: [{
                type: Input
            }], appearance: [{
                type: Input
            }], disabled: [{
                type: Input
            }], selected: [{
                type: Input
            }], wide: [{
                type: Input
            }], styles: [{
                type: Input
            }], onClick: [{
                type: Output
            }], onFocus: [{
                type: Output
            }], onBlur: [{
                type: Output
            }] } });

const names = [
    'chatweb',
    'email',
    'facebook',
    'instagram',
    'phone',
    'whatsapp',
    'booking',
    'expedia',
];
const themes = ['dark', 'light'];
const variations = [
    'contrast',
    'default',
    'disabled',
    'grey',
    'inverse',
];

class CustomIconsRegisterService {
    constructor(matIconRegistry, domSanitizer, theme) {
        this.matIconRegistry = matIconRegistry;
        this.domSanitizer = domSanitizer;
        this.theme = theme;
        this.register();
    }
    register() {
        const icons = this.getIconSrcs();
        for (const cIcon of icons) {
            this.matIconRegistry.addSvgIcon(cIcon, this.domSanitizer.bypassSecurityTrustResourceUrl(`assets/icons/proprietary/${cIcon}.svg`));
        }
    }
    getIcon$(name, variations) {
        return this.theme.listenThemeChange().pipe(map((theme) => `${theme}-${name}-${variations}`));
    }
    hasIcon(name) {
        return names.includes(name);
    }
    getIconSrcs() {
        let _icons = [];
        for (const theme of themes) {
            for (const variation of variations) {
                for (const name of names) {
                    _icons.push(`${theme}-${name}-${variation}`);
                }
            }
        }
        return _icons;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: CustomIconsRegisterService, deps: [{ token: i1$1.MatIconRegistry }, { token: i2.DomSanitizer }, { token: i3.ThemeService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: CustomIconsRegisterService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: CustomIconsRegisterService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: i1$1.MatIconRegistry }, { type: i2.DomSanitizer }, { type: i3.ThemeService }] });

class IconComponent extends SizeableDirective {
    constructor(customIconRegister) {
        super();
        this.customIconRegister = customIconRegister;
        this.name = '';
        this.appearance = 'default';
        this.theme = 'light';
        this.matFontSet = 'material-icons';
        this.fontIcon = '';
        this.svgIcon = '';
        this.filePath = '';
    }
    ngOnInit() {
        this.prepareIcon();
    }
    ngOnChanges() {
        this.prepareIcon();
    }
    ngOnDestroy() {
        this.iconSubscription?.unsubscribe();
    }
    prepareIcon() {
        this.iconSubscription?.unsubscribe();
        if (this.isImageFilePath(this.name)) {
            this.filePath = this.name;
        }
        else if (this.customIconRegister.hasIcon(this.name)) {
            this.iconSubscription = this.prepareCustomIconName().subscribe((iconName) => {
                this.svgIcon = iconName;
            });
        }
        else {
            this.fontIcon = this.name;
        }
    }
    prepareCustomIconName() {
        let appearance = this.appearance;
        if (this.disabled)
            appearance = 'disabled';
        return this.customIconRegister.getIcon$(this.name, appearance);
    }
    isImageFilePath(path) {
        return /\.(jpe?g|png|gif|bmp|webp|tiff|svg?)$/i.test(path);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: IconComponent, deps: [{ token: CustomIconsRegisterService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.12", type: IconComponent, isStandalone: true, selector: "app-icon", inputs: { name: "name", appearance: "appearance", theme: "theme", color: "color", matFontSet: "matFontSet" }, providers: [
            { provide: SizeableDirective, useExisting: IconComponent },
            CustomIconsRegisterService
        ], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "@if (this.svgIcon || this.fontIcon) {\n<mat-icon\n  inline\n  [style.color]=\"color\"\n  [fontSet]=\"matFontSet\"\n  [svgIcon]=\"svgIcon\"\n  >{{ fontIcon }}</mat-icon\n>\n} @if (this.filePath) {\n<img [src]=\"this.filePath\" alt=\"\" srcset=\"\" class=\"img\" />\n}\n", styles: [":host{line-height:1}.img{width:inherit;height:inherit}\n"], dependencies: [{ kind: "ngmodule", type: MatIconModule }, { kind: "component", type: i1$1.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: IconComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-icon', standalone: true, imports: [MatIconModule], providers: [
                        { provide: SizeableDirective, useExisting: IconComponent },
                        CustomIconsRegisterService
                    ], template: "@if (this.svgIcon || this.fontIcon) {\n<mat-icon\n  inline\n  [style.color]=\"color\"\n  [fontSet]=\"matFontSet\"\n  [svgIcon]=\"svgIcon\"\n  >{{ fontIcon }}</mat-icon\n>\n} @if (this.filePath) {\n<img [src]=\"this.filePath\" alt=\"\" srcset=\"\" class=\"img\" />\n}\n", styles: [":host{line-height:1}.img{width:inherit;height:inherit}\n"] }]
        }], ctorParameters: () => [{ type: CustomIconsRegisterService }], propDecorators: { name: [{
                type: Input,
                args: [{ required: true }]
            }], appearance: [{
                type: Input
            }], theme: [{
                type: Input
            }], color: [{
                type: Input
            }], matFontSet: [{
                type: Input
            }] } });

/*
 * Public API Surface of asksuite-livechat-logger
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ButtonV2Component, IconComponent, LoggerModule, LoggerService };
//# sourceMappingURL=asksuite-livechat-frontend-libs.mjs.map
